"""
Models module for BISINDO Trans.
Contains N-gram and Neural language models.
"""

from bisindotrans.models.ngram import ModelNgram

# Neural model is optional (requires torch + transformers)
try:
    from bisindotrans.models.neural import ModelNeural
    HAS_NEURAL = True
except ImportError:
    ModelNeural = None
    HAS_NEURAL = False

__all__ = ["ModelNgram", "ModelNeural", "HAS_NEURAL"]
