"""
BISINDO Trans - Penerjemah Bahasa Isyarat Indonesia

Library untuk menerjemahkan glosa bahasa isyarat ke teks bahasa Indonesia
menggunakan Statistical N-gram dan Neural Language Model.

Usage:
    from bisindotrans import Translator
    
    translator = Translator(model_type="ngram")
    result = translator.translate("SAYA MAKAN NASI")
    print(result)  # "Saya makan nasi."
"""

__version__ = "1.1.1"
__author__ = "Muhammad Aldi Alfatih"

# Public API
from bisindotrans.translator import Translator

# Expose submodules for advanced usage
from bisindotrans import preprocessing
from bisindotrans import models
from bisindotrans import decoding

__all__ = [
    "Translator",
    "preprocessing",
    "models", 
    "decoding",
    "__version__",
]
