"""
Preprocessing module for BISINDO Trans.
Contains normalization and naturalization functions.
"""

from bisindotrans.preprocessing.normalisasi import normalisasi_glosa
from bisindotrans.preprocessing.naturalisasi import naturalisasi_aturan

__all__ = ["normalisasi_glosa", "naturalisasi_aturan"]
